## PyFunge version 0.2 -- http://pyfunge.kldp.net/
## Copyright (c) 2004, Kang Seonghoon (Tokigun).
## This program is distributable under the MIT license.
##
## $Id: exception.py,v 1.3 2004/06/10 16:04:22 tokigun Exp $

"""exception module in PyFunge 0.2 -- http://pyfunge.kldp.net/
This program is distributable under the MIT license.
$Id: exception.py,v 1.3 2004/06/10 16:04:22 tokigun Exp $

This module implements exceptions which can be raised in PyFunge modules.
There are currently 8 exceptions. More exceptions will be added soon.


Table of hierarchy
==================

RuntimeError in __builtins__
 |
 |   < PyFunge.space module >
 +-- NumberOfDimensionError
 +-- EmptyCellError
 +-- NonDefinedCellError
 |
 |   < PyFunge.stack module >
 +-- StackUnderflowError
 +-- SStackUnderflowError
 |
 |   < PyFunge.execute module >
 +-- ExecStopError
 +-- ExecQuitError
 +-- DivisionByZeroError
"""

class NumberOfDimensionError(RuntimeError):
	"""This exception is raised when wrong number of dimension is set."""
class EmptyCellError(RuntimeError):
	"""This exception is raised when the requested cell is empty."""
class NonDefinedCellError(RuntimeError):
	"""This exception is raised when the requested cell is undefined. (i.e. outside the Funge-space)"""

class StackUnderflowError(RuntimeError):
	"""This exception is raised when there is no cell in the top of stack stack when pop."""
class SStackUnderflowError(RuntimeError):
	"""This exception is raised when there is only one stack in stack stack when pop."""

class ExecStopError(RuntimeError):
	"""This exception is raised when current IP is stopped by "@" Stop instruction."""
class ExecQuitError(RuntimeError):
	"""This exception is raised when current program is terminated by "q" Quit instruction."""
class DivisionByZeroError(RuntimeError):
	"""This exception is raised when some number is divided by zero in "/" Divide or "%" Remainder instruction."""
